summaryrefslogtreecommitdiffstats
path: root/sys/netgraph/ng_base.c
diff options
context:
space:
mode:
authormarcel <marcel@FreeBSD.org>2004-07-10 21:45:58 +0000
committermarcel <marcel@FreeBSD.org>2004-07-10 21:45:58 +0000
commitfdfd8c5336e229e2487b1c498b0934230ff167b6 (patch)
tree4591cc1723fc3fc587f4893226a4cb7a6b8420e2 /sys/netgraph/ng_base.c
parent7fd91e098499950141b8f1d34cbac8b2c275ee02 (diff)
downloadFreeBSD-src-fdfd8c5336e229e2487b1c498b0934230ff167b6.zip
FreeBSD-src-fdfd8c5336e229e2487b1c498b0934230ff167b6.tar.gz
Update for the KDB framework:
o Call kdb_enter() instead of Debugger(). o Change comments accordingly.
Diffstat (limited to 'sys/netgraph/ng_base.c')
-rw-r--r--sys/netgraph/ng_base.c7
1 files changed, 4 insertions, 3 deletions
diff --git a/sys/netgraph/ng_base.c b/sys/netgraph/ng_base.c
index c12eae1..c18a577 100644
--- a/sys/netgraph/ng_base.c
+++ b/sys/netgraph/ng_base.c
@@ -47,6 +47,7 @@
#include <sys/param.h>
#include <sys/systm.h>
#include <sys/errno.h>
+#include <sys/kdb.h>
#include <sys/kernel.h>
#include <sys/limits.h>
#include <sys/malloc.h>
@@ -322,7 +323,7 @@ ng_alloc_node(void)
#define NG_FREE_ITEM_REAL(item) do { FREE((item), M_NETGRAPH_ITEM); } while (0)
/* Set this to Debugger("X") to catch all errors as they occur */
#ifndef TRAP_ERROR
#define TRAP_ERROR()
#endif
@@ -3366,12 +3367,12 @@ ng_setisr(node_p node)
do { \
if (NGI_NODE(item) ) { \
printf("item already has node"); \
- Debugger("has node"); \
+ kdb_enter("has node"); \
NGI_CLR_NODE(item); \
} \
if (NGI_HOOK(item) ) { \
printf("item already has hook"); \
- Debugger("has hook"); \
+ kdb_enter("has hook"); \
NGI_CLR_HOOK(item); \
} \
} while (0)
@@ -322,7 +323,7 @@ ng_alloc_node(void)
#define NG_FREE_ITEM_REAL(item) do { FREE((item), M_NETGRAPH_ITEM); } while (0)
-/* Set this to Debugger("X") to catch all errors as they occur */
+/* Set this to kdb_enter("X") to catch all errors as they occur */
#ifndef TRAP_ERROR
#define TRAP_ERROR()
OpenPOWER on IntegriCloud